summaryrefslogtreecommitdiff
path: root/ui/app/components/main_panel/section_layout.js
diff options
context:
space:
mode:
Diffstat (limited to 'ui/app/components/main_panel/section_layout.js')
-rw-r--r--ui/app/components/main_panel/section_layout.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/app/components/main_panel/section_layout.js b/ui/app/components/main_panel/section_layout.js
index e2f1ae17..1c06ab28 100644
--- a/ui/app/components/main_panel/section_layout.js
+++ b/ui/app/components/main_panel/section_layout.js
@@ -12,7 +12,7 @@ export default class SectionLayout extends React.Component {
icon: null, // icon name
buttons: null, // button content
status: null, // must be one of: on, off, unknown, wait, disabled,
// starting, stopping, failure
header: null, // the first line content
body: null, // expanded content
message: null, // alert content
@@ -39,7 +39,7 @@ export default class SectionLayout extends React.Component {
status = "wait"
} else if (status == "stopping") {
status = "wait"
- } else if (status == "failure") {
+ } else if (status == "failed") {
status = "error"
}
@@ -12,7 +12,7 @@ export default class SectionLayout extends React.Component {
buttons: null, // button content
status: null, // must be one of: on, off, unknown, wait, disabled,
- // starting, stopping, failure
+ // starting, stopping, failed
header: null, // the first line content
body: null, // expanded content